@@ -16,5 +16,10 @@ mod bindings {
 
 pub use bindings::*;
 
-#[cfg(not(any(target_os = "macos", target_os = "ios", target_os = "windows")))]
+#[cfg(not(any(
+    target_os = "macos",
+    target_os = "ios",
+    target_os = "windows",
+    target_os = "android"
+)))]
 pub use _frida_g_object_unref as g_object_unref;
